==> deepin-app-store_5.6.3.9.orig.tar.xz: deepin-app-store-5.6.3.9/translations/deepin-app-store_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="235"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="41"/>
        <source>Clear cache</source>
        <translation>Cache opschonen</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="44"/>
        <source>Privacy Policy</source>
        <translation>Privacybeleid</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Opnieuw uitvoeren</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="115"/>
        <source>App Store</source>
        <translation>Appwinkel</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="116"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation>Appwinkel is een softwarecentrum met diverse kwalitatieve programma&apos;s die met één muisklik ge(de)ïnstalleerd kunnen worden.</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation>Zoeken naar &apos;%1&apos; in de winkel</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation>Zoeken naar &apos;%1&apos; in de winkel</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Mijn reacties</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Mijn programma&apos;s</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Uitloggen</translation>
    </message>
</context>
</TS>

==> deepin-app-store_6.2.0.30.orig.tar.xz: deepin-app-store-6.2.0.30/translations/deepin-app-store_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="250"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="43"/>
        <source>Clear cache</source>
        <translation>Cache opschonen</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation type="vanished">Privacybeleid</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Opnieuw uitvoeren</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="61"/>
        <source>App Store</source>
        <translation>Appwinkel</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="62"/>
        <source>App Store is a software center with diverse and quality applications, supporting installation and uninstallation with one click.</source>
        <translation>Appwinkel is een softwarecentrum met diverse kwalitatieve programma&apos;s die met één muisklik ge(de)ïnstalleerd kunnen worden.</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_app_store.cpp" line="71"/>
        <location filename="../src/app/deepin_app_store.cpp" line="73"/>
        <source>UnionTech Software Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <source>Search for &quot;%1&quot; in Store</source>
        <translation>Zoeken naar &apos;%1&apos; in de winkel</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Store</source>
        <translation>Zoeken naar &apos;%1&apos; in de winkel</translation>
    </message>
</context>
<context>
    <name>dstore::AccountProxy</name>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="35"/>
        <source>Activate</source>
        <translation>Activeren</translation>
    </message>
    <message>
        <location filename="../src/ui/channel/account_proxy.cpp" line="44"/>
        <source>Your system is not activated. Please activate as soon as possible for normal use.</source>
        <translation>Je systeem is niet geactiveerd. Doe dit zo spoedig mogelijk om normaal door te kunnen werken.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Mijn reacties</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Mijn programma&apos;s</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Uitloggen</translation>
    </message>
</context>
</TS>
